require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module Fairpay2
    module Account
      # Value object containing attributes to set on a Client Account entity.
      class ClientAccountSetAttributes < UU::OS::REST::DTO

        # Name of the Client Account.
        # Cannot be longer than 250 characters and can contain only allowed characters. The create command fails otherwise.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of the Client Account.
        # The code must be unique in target territory. It cannot be empty string nor longer than 250 characters and can contain only allowed characters.
        # The create command will fail otherwise.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of created Client Account. Cannot be longer than 4000 characters.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # URI of Company for created client account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :company_uri

        # Account number for created client account. Cannot be longer than 250 characters.
        # @param [String]
        # @return [String]
        attr_accessor :account_number

        # Account currency for created client account. Cannot be longer than 250 characters.
        # @param [String]
        # @return [String]
        attr_accessor :account_currency


        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end


        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end


        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def company_uri
          attributes[:companyUri]
        end

        def company_uri=(val)
          if val
            attributes[:companyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:companyUri] = nil
          end
        end

        def account_number
          attributes[:accountNumber]
        end

        def account_number=(val)
          attributes[:accountNumber] = val
        end

        def account_currency
          attributes[:accountCurrency]
        end

        def account_currency=(val)
          attributes[:accountCurrency] = val
        end

      end
    end
  end
end

