require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module Fairpay2
    module BusinessCase
      # Value object representing data of Client Account Business Case entity.
      class ClientAccountBusinessCaseAttributes < UU::OS::REST::DTO
        # @see ClientAccountBusinessCase

        # URI of the Client Account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :uri

        # URI of meta artifact of created Client Account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :meta_artifact_uri

        # Name of created Client Account.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of created Client Account.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of created Client Account.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # URI of the role competent for created Client Account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :competent_role_uri

        # URI of container of the Client Account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :location_uri

        # URI of organizational unit of the Client Account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :organizational_unit_uri

        # Security level of the Client Account.
        # @param [UU::OS::Artifact::SecurityLevel]
        # @return [UU::OS::Artifact::SecurityLevel]
        attr_accessor :security_level

        # Creation stamp of the Client Account.
        # @param [String, Time]
        # @return [String]
        attr_accessor :creation_stamp

        # Creation time of the Client Account.
        # @param [String, Time]
        # @return [String]
        attr_accessor :creation_time

        # Modification stamp of the Client Account.
        # @param [String, Time]
        # @return [String]
        attr_accessor :modification_stamp

        # Modification time of the Client Account.
        # @param [String, Time]
        # @return [String]
        attr_accessor :modification_time

        # Timestamp and UUID of user who updated the Client Account Contract for the last time.
        # @param [String, Time]
        # @return [String]
        attr_accessor :last_mod_stamp

        # Version of the Client Account.
        # @param [String]
        # @return [String]
        attr_accessor :version

        # Name of current state of the Client Account.
        # @param [String]
        # @return [String]
        attr_accessor :state_name

        # Comment of current state of the Client Account.
        # @param [String]
        # @return [String]
        attr_accessor :state_comment

        # Type of current state of the Client Account.
        # @param [UU::OS::Artifact::ArtifactStateType]
        # @return [UU::OS::Artifact::ArtifactStateType]
        attr_accessor :state_type

        # Flag of width of sheets of the Client Account.
        # @param [UU::OS::Artifact::ArtifactWidthType]
        # @return [UU::OS::Artifact::ArtifactWidthType]
        attr_accessor :width

        # UESURI of the entity type of the artifact
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :entity_type_uri

        # URI of the icon of the Client Account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :icon_uri

        # User universe id of client.
        # @param [String]
        # @return [String]
        attr_accessor :user_universe_id

        # Daily withdrawal limit of the related Account.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :daily_limit

        # Weekly withdrawal limit of the related Account.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :weekly_limit

        # Monthly withdrawal limit of the related Account.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :monthly_limit

        # Account number of the client.
        # @param [String]
        # @return [String]
        attr_accessor :client_account_number

        # Client uuEE universe id on Client Account Business Case.
        # @param [String]
        # @return [String]
        attr_accessor :client_uuee_universe_id

        # Avalible balance on Client Account Business Case.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :available_balance

        # Current balance on Client Account Business Case.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :current_balance

        # Authorized Persons on Client Account Business Case.
        # @param [String]
        # @return [String]
        attr_accessor :authorized_persons

        # Authorized Accounts on Client Account Business Case.
        # @param [String]
        # @return [String]
        attr_accessor :authorized_accounts

        # Currency code on Client Account Business Case.
        # @param [String]
        # @return [String]
        attr_accessor :currency_code


        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def user_universe_id
          attributes[:userUniverseId]
        end

        def user_universe_id=(val)
          attributes[:userUniverseId] = val
        end

        def daily_limit
          attributes[:dailyLimit]
        end

        def daily_limit=(val)
          attributes[:dailyLimit] = val
        end

        def weekly_limit
          attributes[:weeklyLimit]
        end

        def weekly_limit=(val)
          attributes[:weeklyLimit] = val
        end

        def monthly_limit
          attributes[:monthlyLimit]
        end

        def monthly_limit=(val)
          attributes[:monthlyLimit] = val
        end

        def client_account_number
          attributes[:clientAccountNumber]
        end

        def client_account_number=(val)
          attributes[:clientAccountNumber] = val
        end

        def client_uuee_universe_id
          attributes[:clientUueeUniverseId]
        end

        def client_uuee_universe_id=(val)
          attributes[:clientUueeUniverseId] = val
        end

        def available_balance
          attributes[:availableBalance]
        end

        def available_balance=(val)
          attributes[:availableBalance] = val
        end

        def current_balance
          attributes[:currentBalance]
        end

        def current_balance=(val)
          attributes[:currentBalance] = val
        end

        def authorized_persons
          attributes[:authorizedPersons]
        end

        def authorized_persons=(val)
          attributes[:authorizedPersons] = val
        end

        def authorized_accounts
          attributes[:authorizedAccounts]
        end

        def authorized_accounts=(val)
          attributes[:authorizedAccounts] = val
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def state_name
          attributes[:stateName]
        end

        def state_name=(val)
          attributes[:stateName] = val
        end

        def state_comment
          attributes[:stateComment]
        end

        def state_comment=(val)
          attributes[:stateComment] = val
        end

        def state_type
          attributes[:stateType]
        end

        def state_type=(val)
          attributes[:stateType] = val
        end

        def width
          attributes[:width]
        end

        def width=(val)
          attributes[:width] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def created_stamp
          attributes[:createdStamp]
        end

        def created_stamp=(val)
          attributes[:createdStamp] = val
        end

        def last_mod_stamp
          attributes[:lastModStamp]
        end

        def last_mod_stamp=(val)
          attributes[:lastModStamp] = val
        end

        def currency_code
          attributes[:currencyCode]
        end

        def currency_code=(val)
          attributes[:currencyCode] = val
        end

      end
    end
  end
end

