require 'uu/os/qos/qos_handler'
require 'uu/os/rest'
require 'uu/os/uesuri'
require 'uu/os/rest/paging_criteria'
require 'uu/fairpay2/businesscase/client_account_business_case_search_query'
require 'uu/fairpay2/businesscase/client_account_business_case_attributes'

# Module Unicorn Universe.
module UU
  # module Fairpay2.
  module Fairpay2
    # Module Business Case.
    module BusinessCase
      # Module Client Account Business Case.
      # This service allows searching at Client Account Business Case(CABC).
      module ClientAccountBusinessCaseSearch
        extend self

        # Service path
        PATH = 'uu/fairpay2/businesscase/ClientAccountBusinessCaseSearch'

        # Retrieves a result list of Client Account Business Cases for territory specified by main entity UESURI.
        # The resulting attachment list is filtered according to the criteria provided by the criteria attribute.
        #
        # @param [UU::OS::UESURI] territory_uri UESURI of the client account business case.
        # @param [UU::Fairpay2::BusinessCase::ClientAccountBusinessCaseSearchQuery] criteria DTO containing paging and filtering criteria. Available parameters is: {ClientAccountBusinessCaseAttributes#client_account_number clientAccountNumber}.
        # @option criteria [String] :query The UES query string. It has to conform the ues query syntax (see documentation for more info). Filtering and order of the result list can be specified there.
        #
        # @return [UU::OS::REST::ResultList<UU::Fairpay2::BusinessCase::ClientAccountBusinessCaseSearchQuery, UU::Fairpay2::BusinessCase::ClientAccountBusinessCaseAttributes>] List of Client Account Business Cases.
        #
        #
        # @example
        #      # Territory URI, where we want to get Client Account Business Cases.
        #      territory_uri = UU::OS::UESURI.new('ues:TERRITORY:TERRITORY');
        #
        #      # Get Client Account Business Case by client_account_number
        #      UU::Fairpay2::BusinessCase::ClientAccountBusinessCaseSearch.query(territory_uri,
        #       :query => "clientAccountNumber = '12345'");
        def query(territory_uri, criteria = nil)
          svc = UU::OS::REST::RemoteClient.new(ClientAccountBusinessCaseSearch)
          dto = UU::Fairpay2::BusinessCase::ClientAccountBusinessCaseSearchQuery.new(criteria)
          svc.add_parameter('pageIndex', dto.page_index)
          svc.add_parameter('pageSize', dto.page_size)
          svc.add_parameter('query', dto.query)
          UU::OS::QoS::QoSHandler.auto_retry do
            res = svc.get('query', territory_uri)
            return UU::OS::REST::ResultList.new(UU::Fairpay2::BusinessCase::ClientAccountBusinessCaseSearchQuery, UU::Fairpay2::BusinessCase::ClientAccountBusinessCaseAttributes, res)
          end
        end

      end
    end
  end
end
