require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module Fairpay2
    module FinancialTransaction

      class BankTransactionCreate < UU::OS::REST::DTO

        # Name of the bank transaction.
        # The value is trimmed. If null is set, the name is taken from the meta artifact.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of the bank transaction.
        # The value is trimmed. If null is set, the code is generated automatically.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of the Bank Transaction.
        # Cannot be longer than 4000 characters.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # URI of the role competent for the Bank Transaction.
        # Cannot be null or longer than 4000 characters. Must be valid UESURI.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :competent_role_uri

        # URI of the meta artifact.
        # Required attribute, cannot be null or invalid UESURI.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :meta_artifact_uri

        # Security level.
        # @param [UU::OS::Artifact::SecurityLevel]
        # @return [UU::OS::Artifact::SecurityLevel]
        attr_accessor :security_level

        # Amount of the Bank Transaction.
        # Required attribute, cannot be null or invalid Fixnum.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount

        # Constant symbol.
        # @param [String]
        # @return [String]
        attr_accessor :constant_symbol

        # Currency code.
        # Required attribute, cannot be null or longer than 250 characters.
        # @param [String]
        # @return [String]
        attr_accessor :currency

        # UESURI of the debit business case or Client Account Business Case.
        # Required attribute, cannot be null or invalid UESURI
        # @param [String]
        # @return [String]
        attr_accessor :debit_business_case_uri

        # Specific symbol.
        # @param [String]
        # @return [String]
        attr_accessor :specific_symbol

        # Variable symbol.
        # @param [String]
        # @return [String]
        attr_accessor :variable_symbol

        # Message for recipient.
        # @param [String]
        # @return [String]
        attr_accessor :message_recipient

        # Message for payer.
        # @param [String]
        # @return [String]
        attr_accessor :message_payer

        # Uri of Finman transaction. UESURI must be normalized. Attribute is not required. <b>Should be used only
        # in integration script FINMAN->FAIRPAY </b>
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :finman_transaction_uri

        # Uri of org. unit or folder where we want to create Finman transaction. Attribute is required.
        # Cannot be null or empty. Must be valid UESURI.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :location_uri

        # Credit Client Account Number
        # @param [String]
        # @return [String]
        attr_accessor :credit_account_number

        # Debit Client Account Number
        # @param [String]
        # @return [String]
        attr_accessor :debit_account_number

        # Credit Account Currency
        # Required attribute, cannot be null or longer than 250 characters.
        # @param [String]
        # @return [String]
        attr_accessor :credit_account_currency

        # Debit Account Currency
        # Required attribute, cannot be null or longer than 250 characters.
        # @param [String]
        # @return [String]
        attr_accessor :debit_account_currency

        # Exchange rate for opposite side.
        # Required attribute, cannot be null or or empty
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :exchange_rate_for_opp_side

        # Amount for opposite side
        # Required attribute, cannot be null or empty
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_for_opp_side


        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end


        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end


        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end


        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end


        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end


        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end


        def amount
          attributes[:amount]
        end

        def amount=(val)
          attributes[:amount] = val
        end


        def constant_symbol
          attributes[:constantSymbol]
        end

        def constant_symbol=(val)
          attributes[:constantSymbol] = val
        end


        def currency
          attributes[:currency]
        end

        def currency=(val)
          attributes[:currency] = val
        end


        def debit_business_case_uri
          attributes[:debitBusinessCaseUri]
        end

        def debit_business_case_uri=(val)
          if val
            attributes[:debitBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitBusinessCaseUri] = nil
          end
        end


        def specific_symbol
          attributes[:specificSymbol]
        end

        def specific_symbol=(val)
          attributes[:specificSymbol] = val
        end


        def variable_symbol
          attributes[:variableSymbol]
        end

        def variable_symbol=(val)
          attributes[:variableSymbol] = val
        end


        def message_recipient
          attributes[:messageRecipient]
        end

        def message_recipient=(val)
          attributes[:messageRecipient] = val
        end


        def message_payer
          attributes[:messagePayer]
        end

        def message_payer=(val)
          attributes[:messagePayer] = val
        end


        def finman_transaction_uri
          attributes[:finmanTransactionUri]
        end

        def finman_transaction_uri=(val)
          if val
            attributes[:finmanTransactionUri] = UU::OS::UESURI.new(val)
          else
            attributes[:finmanTransactionUri] = nil
          end
        end


        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end


        def credit_account_number
          attributes[:creditAccountNumber]
        end

        def credit_account_number=(val)
          attributes[:creditAccountNumber] = val
        end


        def debit_account_number
          attributes[:debitAccountNumber]
        end

        def debit_account_number=(val)
          attributes[:debitAccountNumber] = val
        end


        def credit_account_currency
          attributes[:creditAccountCurrency]
        end

        def credit_account_currency=(val)
          attributes[:creditAccountCurrency] = val
        end


        def debit_account_currency
          attributes[:debitAccountCurrency]
        end

        def debit_account_currency=(val)
          attributes[:debitAccountCurrency] = val
        end


        def exchange_rate_for_opp_side
          attributes[:exchangeRateForOppSide]
        end

        def exchange_rate_for_opp_side=(val)
          attributes[:exchangeRateForOppSide] = val
        end


        def amount_for_opp_side
          attributes[:amountForOppSide]
        end

        def amount_for_opp_side=(val)
          attributes[:amountForOppSide] = val
        end


      end
    end
  end
end

